#!/usr/bin/env python3

"""
Utility functions to use with imshowpair().
"""

import skimage

def blend(a, b, alpha=0.5):
    """
    Alpha blend two images.

    Parameters
    ----------
    a, b : numpy.ndarray
        Images to blend.
    alpha : float
        Blending factor.

    Returns
    -------
    result : numpy.ndarray
        Blended image.
    """

    a = skimage.img_as_float(a)
    b = skimage.img_as_float(b)
    return a*alpha+(1-alpha)*b




#!/usr/bin/env python3

# Copyright (c) 2018, Lev E. Givon
# All rights reserved.
# Distributed under the terms of the BSD license:
# http://www.opensource.org/licenses/bsd-license

import matplotlib.pyplot as plt
import numpy as np

def imshowpair(a, b, method=None, show_all=True, axes_visible=False, cmap=None,
               interpolation=None, grid=False, *args, **kwargs):
    """
    Compare images.

    Parameters
    ----------
    a, b : numpy.ndarray
        Images to compare.
    method : callable
        Callable to apply to images. Must support at least two arguments;
        additional specified arguments are passed to `method`.
        If None, both images are displayed side by side.
    show_all : bool
        If True and `method` is defined, display original images
        alongside `method(a, b)`.
    axes_visible : bool
        Show axes if True.
    cmap : matplotlib.colors.Colormap
        Color map to use when displaying images.
    interpolation : str
        Interpolation method for `imshow` to use.
    grid : bool
        If True, display grid.
    """

    def turn_off_ticks(ax):
        for tic in ax.xaxis.get_major_ticks():
            tic.tick1On = tic.tick2On = False
        for tic in ax.yaxis.get_major_ticks():
            tic.tick1On = tic.tick2On = False

    a = np.asarray(a)
    b = np.asarray(b)
    a_shape = a.shape
    b_shape = b.shape

    ax_list = []
    if method == None:
        ax0 = ax = plt.subplot(121)
        plt.imshow(a, origin='upper', cmap=cmap, interpolation=interpolation)
        plt.grid(grid)
        turn_off_ticks(ax)
        ax_list.append(ax)
        ax = plt.subplot(122, sharex=ax0, sharey=ax0)
        plt.imshow(b, origin='upper', cmap=cmap, interpolation=interpolation)
        plt.grid(grid)
        turn_off_ticks(ax)
        if a_shape == b_shape:
            ax.set_yticklabels([])
        ax_list.append(ax)
        plt.subplots_adjust()
    elif callable(method):
        c = method(a, b, *args, **kwargs)
        c_shape = c.shape
        if show_all:
            ax0 = ax = plt.subplot(131)
            plt.imshow(a, origin='upper', cmap=cmap, interpolation=interpolation)
            plt.grid(grid)
            turn_off_ticks(ax)
            ax_list.append(ax)
            ax = plt.subplot(132, sharex=ax0, sharey=ax0)
            plt.imshow(b, origin='upper', cmap=cmap, interpolation=interpolation)
            plt.grid(grid)
            turn_off_ticks(ax)
            if a_shape == b_shape:
                ax.set_yticklabels([])
            ax_list.append(ax)
            ax = plt.subplot(133, sharex=ax0, sharey=ax0)
            plt.imshow(c, origin='upper', cmap=cmap, interpolation=interpolation)
            plt.grid(grid)
            turn_off_ticks(ax)
            plt.subplots_adjust()
            if c_shape == b_shape:
                ax.set_yticklabels([])
            ax_list.append(ax)
        else:
            ax = plt.subplot(111)
            plt.imshow(c, origin='upper', cmap=cmap, interpolation=interpolation)
            plt.grid(grid)           
            turn_off_ticks(ax)
            if c_shape == b_shape:
                ax.set_yticklabels([])
            ax_list.append(ax)
    else:
        NotImplementedError
    if not axes_visible:
        for ax in ax_list:
            ax.set_xticklabels([])
            ax.set_yticklabels([])



#!/usr/bin/env python

import os
import re

from setuptools import setup

NAME =               'imshowpair'
VERSION =            '0.1.0'
AUTHOR =             'Lev E. Givon'
AUTHOR_EMAIL =       'lev@columbia.edu'
URL =                'https://github.com/lebedov/imshowpair'
DESCRIPTION =        'Compare two images'
with open('README.rst', 'r') as f:
    LONG_DESCRIPTION = f.read()
LONG_DESCRIPTION = re.search('.*(^Package Description.*)', LONG_DESCRIPTION, re.MULTILINE|re.DOTALL).group(1)
DOWNLOAD_URL =       URL
LICENSE =            'BSD'
CLASSIFIERS = [
    'Development Status :: 3 - Alpha',
    'Intended Audience :: Developers',
    'Intended Audience :: Science/Research',
    'License :: OSI Approved :: BSD License',
    'Operating System :: OS Independent',
    'Programming Language :: Python',
    'Programming Language :: Python :: 2.7',
    'Programming Language :: Python :: 3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Topic :: Scientific/Engineering',
    'Topic :: Software Development']

if __name__ == "__main__":
    if os.path.exists('MANIFEST'):
        os.remove('MANIFEST')

    setup(
        name = NAME,
        version = VERSION,
        author = AUTHOR,
        author_email = AUTHOR_EMAIL,
        license = LICENSE,
        classifiers = CLASSIFIERS,
        description = DESCRIPTION,
        long_description = LONG_DESCRIPTION,
        url = URL,
        py_modules = ['imshowpair'],
        install_requires = ['matplotlib>=2.0.0'],
        extras_require = {'extra_funcs': ['scikit-image>=0.14']}
        )
